@@ -2,11 +2,11 @@
 #' 
 #' This function tried to determine whether an object is an image that the
 #' package knows how to handle. If its class is \code{"nifti"},
-#' \code{"niftiImage"} or \code{"internalImage"}, then the result is always
-#' \code{TRUE}. Likewise if it has an internal image pointer (although in that
-#' case it should also be of class \code{"niftiImage"}). If it has no
-#' \code{dim} attribute, or looks like an affine matrix, then the result is
-#' \code{FALSE}. Otherwise the value of the \code{unsure} argument is returned.
+#' \code{"niftiImage"}, \code{"internalImage"} or \code{"MriImage"}, then the
+#' result is always \code{TRUE}. Likewise if it has an internal image pointer.
+#' If it has no \code{dim} attribute, or looks like an affine matrix, then the
+#' result is \code{FALSE}. Otherwise the value of the \code{unsure} argument
+#' is returned.
 #' 
 #' @param object An R object.
 #' @param unsure The value to return if the function can't tell whether or not
@@ -16,7 +16,7 @@
 #' @export
 isImage <- function (object, unsure = NA)
 {
-    if (any(c("nifti","niftiImage","internalImage") %in% class(object)))
+    if (any(c("nifti","niftiImage","internalImage","MriImage") %in% class(object)))
         return (TRUE)
     else if (!is.null(attr(object, ".nifti_image_ptr")))
         return (TRUE)
@@ -123,10 +123,11 @@ ndim <- function (object)
 
 #' Pixel dimensions and units
 #' 
-#' These functions return the \code{"pixdim"} and \code{"pixunits"} attributes
-#' of their arguments. These represent the physical step size between pixel or
-#' voxel centre points, and the spatial and temporal units that they are given
-#' in. The former defaults to 1 in each dimension, if there is no attribute.
+#' By default, these generic functions return or replace the \code{"pixdim"}
+#' and \code{"pixunits"} attributes of their arguments. These represent the
+#' physical step size between pixel or voxel centre points, and the spatial and
+#' temporal units that they are given in. The former defaults to 1 in each
+#' dimension, if there is no attribute.
 #' 
 #' @param object An R object, generally an image.
 #' @param value Numeric vector of pixel dimensions along each axis, or
@@ -139,6 +140,14 @@ ndim <- function (object)
 #' @author Jon Clayden <code@@clayden.org>
 #' @export
 pixdim <- function (object)
+{
+    UseMethod("pixdim")
+}
+
+
+#' @rdname pixdim
+#' @export
+pixdim.default <- function (object)
 {
     if (!is.null(attr(object, "pixdim")))
         return (attr(object, "pixdim"))
@@ -152,6 +161,14 @@ pixdim <- function (object)
 #' @rdname pixdim
 #' @export
 "pixdim<-" <- function (object, value)
+{
+    UseMethod("pixdim<-")
+}
+
+
+#' @rdname pixdim
+#' @export
+"pixdim<-.default" <- function (object, value)
 {
     if ("internalImage" %in% class(object))
         stop("Pixel dimensions of an internal image cannot be changed")
@@ -170,6 +187,14 @@ pixdim <- function (object)
 #' @rdname pixdim
 #' @export
 pixunits <- function (object)
+{
+    UseMethod("pixunits")
+}
+
+
+#' @rdname pixdim
+#' @export
+pixunits.default <- function (object)
 {
     if (!is.null(attr(object, "pixunits")))
         return (attr(object, "pixunits"))
@@ -181,6 +206,14 @@ pixunits <- function (object)
 #' @rdname pixdim
 #' @export
 "pixunits<-" <- function (object, value)
+{
+    UseMethod("pixunits<-")
+}
+
+
+#' @rdname pixdim
+#' @export
+"pixunits<-.default" <- function (object, value)
 {
     if ("internalImage" %in% class(object))
         stop("Pixel units of an internal image cannot be changed")
